@@ -13,12 +13,16 @@
 """Database v1 Instances action implementations"""
 
 import argparse
+import six
+
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils as osc_utils
-import six
+from oslo_utils import uuidutils
 
 from troveclient.i18n import _
+from troveclient.osc.v1 import base
+from troveclient import utils as trove_utils
 
 
 def set_attributes_for_print(instances):
@@ -69,10 +73,13 @@ def set_attributes_for_print_detail(instance):
 
 
 class ListDatabaseInstances(command.Lister):
-
     _description = _("List database instances")
     columns = ['ID', 'Name', 'Datastore', 'Datastore Version', 'Status',
                'Flavor ID', 'Size', 'Region']
+    admin_columns = [
+        'ID', 'Name', 'Tenant ID', 'Datastore', 'Datastore Version', 'Status',
+        'Flavor ID', 'Size'
+    ]
 
     def get_parser(self, prog_name):
         parser = super(ListDatabaseInstances, self).get_parser(prog_name)
@@ -103,19 +110,34 @@ class ListDatabaseInstances(command.Lister):
                    "deprecated in the future, retaining just "
                    "--include_clustered.")
         )
+        parser.add_argument(
+            '--all-projects',
+            dest='all_projects',
+            action="store_true",
+            default=False,
+            help=_("Include database instances of all projects (admin only)")
+        )
         return parser
 
     def take_action(self, parsed_args):
-        db_instances = self.app.client_manager.database.instances
-        instances = db_instances.list(limit=parsed_args.limit,
-                                      marker=parsed_args.marker,
-                                      include_clustered=(parsed_args.
-                                                         include_clustered))
+        if parsed_args.all_projects:
+            db_instances = self.app.client_manager.database.mgmt_instances
+            cols = self.admin_columns
+        else:
+            db_instances = self.app.client_manager.database.instances
+            cols = self.columns
+
+        instances = db_instances.list(
+            limit=parsed_args.limit,
+            marker=parsed_args.marker,
+            include_clustered=parsed_args.include_clustered
+        )
         if instances:
             instances = set_attributes_for_print(instances)
-            instances = [osc_utils.get_item_properties(i, self.columns)
+            instances = [osc_utils.get_item_properties(i, cols)
                          for i in instances]
-        return self.columns, instances
+
+        return cols, instances
 
 
 class ShowDatabaseInstance(command.ShowOne):
@@ -137,29 +159,41 @@ class ShowDatabaseInstance(command.ShowOne):
         return zip(*sorted(six.iteritems(instance)))
 
 
-class DeleteDatabaseInstance(command.Command):
-
+class DeleteDatabaseInstance(base.TroveDeleter):
     _description = _("Deletes an instance.")
 
     def get_parser(self, prog_name):
         parser = super(DeleteDatabaseInstance, self).get_parser(prog_name)
         parser.add_argument(
             'instance',
-            metavar='<instance>',
-            help=_('ID or name of the Instance'),
+            nargs='+',
+            metavar='instance',
+            help='Id or name of instance(s).'
         )
         return parser
 
     def take_action(self, parsed_args):
         db_instances = self.app.client_manager.database.instances
-        try:
-            instance = osc_utils.find_resource(db_instances,
-                                               parsed_args.instance)
-            db_instances.delete(instance)
-        except Exception as e:
-            msg = (_("Failed to delete instance %(instance)s: %(e)s")
-                   % {'instance': parsed_args.instance, 'e': e})
-            raise exceptions.CommandError(msg)
+
+        # Used for batch deletion
+        self.delete_func = db_instances.delete
+        self.resource = 'database instance'
+
+        ids = []
+        for instance_id in parsed_args.instance:
+            if not uuidutils.is_uuid_like(instance_id):
+                try:
+                    instance_id = trove_utils.get_resource_id_by_name(
+                        db_instances, instance_id
+                    )
+                except Exception as e:
+                    msg = ("Failed to get database instance %s, error: %s" %
+                           (instance_id, str(e)))
+                    raise exceptions.CommandError(msg)
+
+            ids.append(instance_id)
+
+        self.delete_resources(ids)
 
 
 class CreateDatabaseInstance(command.ShowOne):
