@@ -248,8 +248,8 @@ class Backups(base.ManagerWithFind):
         def execution_list_generator():
             yielded = 0
             for sexec in mistral_execution_generator():
-                if (sexec.workflow_name == cron_trigger.workflow_name
-                        and ct_input == json.loads(sexec.input)):
+                if (sexec.workflow_name == cron_trigger.workflow_name and
+                        ct_input == json.loads(sexec.input)):
                     yield ScheduleExecution(self, sexec.to_dict(),
                                             loaded=True)
                     yielded += 1
